pyrasa.irasa\_mne.irasa\_epochs
===============================

.. currentmodule:: pyrasa.irasa_mne

.. autofunction:: irasa_epochs

.. _sphx_glr_backreferences_pyrasa.irasa_mne.irasa_epochs:

.. minigallery:: pyrasa.irasa_mne.irasa_epochs
    :add-heading: